#!/usr/bin/env python
import rospy
from sensor_msgs.msg import LaserScan, PointCloud2
import laser_geometry.laser_geometry as lg

class LaserScanToPointCloud:
    def __init__(self):
        rospy.init_node('scan_to_cloud')
        self.lp = lg.LaserProjection()
        self.scan_sub = rospy.Subscriber('/scan', LaserScan, self.scan_callback)
        self.cloud_pub = rospy.Publisher('/filtered_cloud', PointCloud2, queue_size=10)

    def scan_callback(self, scan_msg):
        # Convert LaserScan to PointCloud2
        cloud_msg = self.lp.projectLaser(scan_msg)
        self.cloud_pub.publish(cloud_msg)

if __name__ == '__main__':
    try:
        LaserScanToPointCloud()
        rospy.spin()
    except rospy.ROSInterruptException:
        pass

